# Open-Genome

Welcome to Open-Genome Toolkit (OGT). Toolkit and data preparation pipeline for the Open-Genome Project.

Open-Genome Project (OGP) is an open-source genome database for all types of AI models, using XAI techniques. We aim to map out areas of interest in various AI models that contribute to the skill & behaviour of AI models. Help researchers, ML engineers & decision makers, better understand & regulate AI development towards a safer, more useful, humanity aligned future.

Read the docs here [https://opengenome.readthedocs.io/en/latest/](https://opengenome.readthedocs.io/en/latest/)

Visit our website here [https://open-genome-project.org](https://open-genome-project.org)

## Installation

```bash
$ pip install opengenome
```

## Usage

Test `opengenome` by trying the welcome function:

```python
import opengenome as og

og.about()
```

or

```bash
$ opengenome-hello
```

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`opengenome` was created by Open-Genome Project Group:

It is licensed under the terms of the GNU General Public License v3.0 license.

## Contibutors

In alphabetical order:

- Anson Cheng Jian Shiun

- Lim Jia Chyuen

- Lu Hou Yang
